@@ -23,16 +23,28 @@
 #include "mmaid.h"
 
 
-/******************************************************************************
-*                                                                             *
-* ja:中断関数群                                                               *
-*                                                                             *
-******************************************************************************/
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 extern gboolean userbreak;
 
 
+/******************************************************************************
+*                                                                             *
+* ja:中断ダイアログ関数群                                                     *
+*                                                                             *
+******************************************************************************/
+/*  ja:中断ダイアログ表示
+    label,説明文                                                            */
 GtkWidget *
 abort_dialog (const gchar *label);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
