@@ -22,8 +22,8 @@
 #include "mm_list.h"
 #include "misc/charuty.h"
 #include "misc/fileio.h"
-#include "misc/misc_charset.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzcharset.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -162,7 +162,7 @@ add_dialog_clicked_ok (GtkWidget   *widget,
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   genre   = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo7)->entry));
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  charset = misc_charset_get_charset (MISC_CHARSET (charset8));
+  charset = orz_charset_get_charset (ORZ_CHARSET (charset8));
   if (file && file[0] != '\0')
     id3tag->file = g_strdup (file);
   if (title[0] != '\0')
@@ -177,7 +177,7 @@ add_dialog_clicked_ok (GtkWidget   *widget,
     id3tag->comment = g_strdup (comment);
   if (genre[0] != '\0')
     id3tag->genre = g_strdup (genre);
-  if (misc_charset_is_valid (MISC_CHARSET (charset8)))
+  if (orz_charset_is_valid (ORZ_CHARSET (charset8)))
     id3tag->charset = charset;
   else
     g_free (charset);
@@ -187,10 +187,10 @@ add_dialog_clicked_ok (GtkWidget   *widget,
   mm_list_set_cursor (MM_LIST (mmaid->list), n, c);
   mm_list_unselect_all (MM_LIST (mmaid->list));
   mm_list_select (MM_LIST (mmaid->list), n);
-  if (misc_charset_is_valid (MISC_CHARSET (charset8)))
+  if (orz_charset_is_valid (ORZ_CHARSET (charset8)))
     charlist_renewal_all (charset);
-  misc_mdi_set_edited (MISC_MDI (mdi), 
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid), TRUE);
+  orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid), TRUE);
   gtk_widget_destroy (dialog);
 }
 
@@ -221,10 +221,10 @@ add_dialog_changed (GtkWidget   *widget,
   gboolean result;
   gchar *charset;
 
-  charset = misc_charset_get_charset (MISC_CHARSET (charset8));
+  charset = orz_charset_get_charset (ORZ_CHARSET (charset8));
   result = mm_list_is_valid_file (MM_LIST (mmaid->list), -1,
                                     gtk_entry_get_text (GTK_ENTRY (entry0)))
-    && (charset[0] == '\0' || misc_charset_is_valid (MISC_CHARSET (charset8)));
+    && (charset[0] == '\0' || orz_charset_is_valid (ORZ_CHARSET (charset8)));
   g_free (charset);
   gtk_widget_set_sensitive (button9, result);
 }
@@ -429,9 +429,9 @@ add_dialog (MmaidWindow *mmaid)
   g_list_free (glist5);
   g_list_free (glist7);
   /* ja:文字符号化方式 */
-  charset8 = misc_charset_new ();
-  misc_charset_add_candidate (MISC_CHARSET (charset8), charset_list);
-  misc_charset_set_charset (MISC_CHARSET (charset8),
+  charset8 = orz_charset_new ();
+  orz_charset_add_candidate (ORZ_CHARSET (charset8), charset_list);
+  orz_charset_set_charset (ORZ_CHARSET (charset8),
                             id3tag && id3tag->charset ? id3tag->charset : "");
   g_signal_connect (G_OBJECT (charset8), "activate",
                                     G_CALLBACK (add_dialog_activate), mmaid);
