@@ -23,15 +23,25 @@
 #include "mmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 /******************************************************************************
 *                                                                             *
 * ja:追加ダイアログ関数群                                                     *
 *                                                                             *
 ******************************************************************************/
-
-
+/*  ja:追加ダイアログ表示
+    mmaid,ウインドウ情報                                                    */
 void
 add_dialog (MmaidWindow *mmaid);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
