@@ -21,8 +21,8 @@
 #include "general.h"
 #include "mm_list.h"
 #include "misc/fileio.h"
-#include "misc/misc_charset.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzcharset.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -170,7 +170,7 @@ edit_dialog_clicked_ok (GtkWidget   *widget,
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   genre   = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo7)->entry));
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  charset = misc_charset_get_charset (MISC_CHARSET (charset8));
+  charset = orz_charset_get_charset (ORZ_CHARSET (charset8));
   t = gtk_label_get_use_markup (GTK_LABEL (label1));
   a = gtk_label_get_use_markup (GTK_LABEL (label2));
   l = gtk_label_get_use_markup (GTK_LABEL (label3));
@@ -217,8 +217,8 @@ edit_dialog_clicked_ok (GtkWidget   *widget,
   g_free (file);
   if (e && charset[0] != '\0')
     charlist_renewal_all (charset);
-  misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid), TRUE);
+  orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid), TRUE);
   gtk_widget_destroy (dialog);
 }
 
@@ -274,9 +274,9 @@ edit_dialog_changed (GtkWidget *widget,
     {
       gchar *charset;
 
-      charset = misc_charset_get_charset (MISC_CHARSET (charset8));
+      charset = orz_charset_get_charset (ORZ_CHARSET (charset8));
       result = charset[0] == '\0'
-                            || misc_charset_is_valid (MISC_CHARSET (charset8));
+                            || orz_charset_is_valid (ORZ_CHARSET (charset8));
       g_free (charset);
     }
   gtk_widget_set_sensitive (button9, result);
@@ -432,12 +432,22 @@ edit_dialog (MmaidWindow *mmaid)
   g_list_free (glist5);
   g_list_free (glist7);
   /* ja:文字符号化方式 */
-  charset8 = misc_charset_new ();
-  misc_charset_add_candidate (MISC_CHARSET (charset8), charset_list);
+  charset8 = orz_charset_new ();
+  orz_charset_add_candidate (ORZ_CHARSET (charset8), charset_list);
   /* ja:コンボボックス&文字符号化方式 */
   if (s == 1)
     {
 #if GTK_CHECK_VERSION(2,4,0)
+      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo1)->child),
+                                    id3tag->title ? id3tag->title : "");
+      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo2)->child),
+                                    id3tag->artist ? id3tag->artist : "");
+      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo3)->child),
+                                    id3tag->album ? id3tag->album : "");
+      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo5)->child),
+                                    id3tag->comment ? id3tag->comment : "");
+      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo7)->child),
+                                    id3tag->genre ? id3tag->genre : "");
 #else /* not GTK_CHECK_VERSION(2,4,0) */
       gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo1)->entry),
                                     id3tag->title ? id3tag->title : "");
@@ -450,7 +460,7 @@ edit_dialog (MmaidWindow *mmaid)
       gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo7)->entry),
                                     id3tag->genre ? id3tag->genre : "");
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-      misc_charset_set_charset (MISC_CHARSET (charset8),
+      orz_charset_set_charset (ORZ_CHARSET (charset8),
                                     id3tag->charset ? id3tag->charset : "");
     }
   else
@@ -499,7 +509,7 @@ edit_dialog (MmaidWindow *mmaid)
       gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo7)->entry),
                                                     g ? id3tag->genre   : "");
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-      misc_charset_set_charset (MISC_CHARSET (charset8),
+      orz_charset_set_charset (ORZ_CHARSET (charset8),
                                                     e ? id3tag->charset : "");
     }
 #if GTK_CHECK_VERSION(2,4,0)
