@@ -21,7 +21,7 @@
 #include "general.h"
 #include "mm_list.h"
 #include "misc/fileio.h"
-#include "misc/misc_charset.h"
+#include "orz/orzcharset.h"
 
 
 /******************************************************************************
@@ -39,7 +39,7 @@ export_dialog_clicked (GtkWidget   *widget,
 {
   *expinfo = g_malloc0 (sizeof (ExportInfo));
   (*expinfo)->gnum = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin));
-  (*expinfo)->charset = misc_charset_get_charset (MISC_CHARSET (charset));
+  (*expinfo)->charset = orz_charset_get_charset (ORZ_CHARSET (charset));
   (*expinfo)->hold = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
   charlist_renewal_all ((*expinfo)->charset);
   gtk_widget_destroy (dialog);
@@ -65,7 +65,7 @@ export_dialog_edited (GtkWidget *widget,
 
   g = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin));
   gtk_widget_set_sensitive (button0, 0 <= g && g <= 255
-                            && misc_charset_is_valid (MISC_CHARSET (charset)));
+                            && orz_charset_is_valid (ORZ_CHARSET (charset)));
 }
 
 
@@ -91,7 +91,7 @@ export_dialog_changed (GtkWidget *widget,
     }
   gtk_label_set_text (GTK_LABEL (label0), str);
   gtk_widget_set_sensitive (button0, 0 <= g && g <= 255
-                            && misc_charset_is_valid (MISC_CHARSET (charset)));
+                            && orz_charset_is_valid (ORZ_CHARSET (charset)));
 }
 
 
@@ -133,9 +133,9 @@ export_dialog (const gchar *def_charset)
   GTK_WIDGET_SET_FLAGS (button0, GTK_CAN_DEFAULT);
   GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT);
   /* ja:文字符号化方式 */
-  charset = misc_charset_new ();
-  misc_charset_add_candidate (MISC_CHARSET (charset), charset_list);
-  misc_charset_set_charset (MISC_CHARSET (charset), def_charset);
+  charset = orz_charset_new ();
+  orz_charset_add_candidate (ORZ_CHARSET (charset), charset_list);
+  orz_charset_set_charset (ORZ_CHARSET (charset), def_charset);
   g_signal_connect (G_OBJECT (charset), "activate",
                                 G_CALLBACK (export_dialog_activate), &expinfo);
   g_signal_connect (G_OBJECT (charset), "edited",
