@@ -24,8 +24,8 @@
 #include "sigmain.h"
 #include "misc/fileio.h"
 #include "misc/misc.h"
-#include "misc/misc_history.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzhistory.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -705,8 +705,6 @@ file_open_edit (const gchar *file)
                                     G_CALLBACK (signal_button_press), mmaid);
   g_signal_connect (G_OBJECT (mmaid->list), "changed",
                                     G_CALLBACK (signal_changed), mmaid);
-  g_signal_connect (G_OBJECT (mmaid->list), "clicked",
-                                    G_CALLBACK (signal_clicked), mmaid);
   g_signal_connect (G_OBJECT (mmaid->list), "deleted",
                                     G_CALLBACK (signal_deleted), mmaid);
   g_signal_connect (G_OBJECT (mmaid->list), "edited",
@@ -715,6 +713,8 @@ file_open_edit (const gchar *file)
                                     G_CALLBACK (signal_inserted), mmaid);
   g_signal_connect (G_OBJECT (mmaid->list), "moved",
                                     G_CALLBACK (signal_moved), mmaid);
+  g_signal_connect (G_OBJECT (mmaid->list), "sorted",
+                                    G_CALLBACK (signal_sorted), mmaid);
   g_signal_connect (G_OBJECT (mmaid->list), "destroy",
                                     G_CALLBACK (signal_destroy_list), mmaid);
   gtk_widget_add_events (mmaid->list, GDK_BUTTON_PRESS_MASK);
@@ -725,7 +725,7 @@ file_open_edit (const gchar *file)
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
                                 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   /* ja:表示 */
-  page_num = misc_mdi_append_page (MISC_MDI (mdi),
+  page_num = orz_mdi_append_page (ORZ_MDI (mdi),
                                             scroll, filename, !file, mmaid);
   gtk_widget_show_all (scroll);
   gtk_notebook_set_page (GTK_NOTEBOOK (mdi), page_num);
@@ -733,7 +733,7 @@ file_open_edit (const gchar *file)
 
   /* ja:新規作成ではなく、ファイルが存在する時には履歴に加える */
   if (file && fileio_isfile (file))
-    misc_history_add_file (MISC_HISTORY (history), file);
+    orz_history_add_file (ORZ_HISTORY (history), file);
   g_free (filename);
 
   return mmaid;
