@@ -22,7 +22,7 @@
 #include "toolbar.h"
 #include "misc/charuty.h"
 #include "misc/misc.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -83,81 +83,101 @@ set_menu_bar (MmaidWindow *mmaid)
                   }
             }
         }
-      created = misc_mdi_get_created (MISC_MDI (mdi),
-                        misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid));
-      gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU
-            (gtk_item_factory_get_widget (ifactory_menu, "<main>/Tag"))),
-                                                                        TRUE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Close"), TRUE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Save"), count);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Save As..."), count);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Reload..."), !created);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Export..."), arrow_select);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Tag/Up"), arrow_up);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Tag/Down"), arrow_down);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Tag/Root..."), count);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Tag/Refresh..."), count);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Tag/Add..."), TRUE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Tag/Edit..."), arrow_select);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Tag/Search..."), TRUE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Tag/Cut"), arrow_select);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Tag/Copy"), arrow_select);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Tag/Delete"), arrow_select);
-      gtk_widget_set_sensitive (toolbar_items[ 2].item, count);
-      gtk_widget_set_sensitive (toolbar_items[ 4].item, arrow_select);
-      gtk_widget_set_sensitive (toolbar_items[ 5].item, arrow_select);
-      gtk_widget_set_sensitive (toolbar_items[ 6].item, TRUE);
-      gtk_widget_set_sensitive (toolbar_items[ 7].item, arrow_select);
-      gtk_widget_set_sensitive (toolbar_items[ 9].item, count);
-      gtk_widget_set_sensitive (toolbar_items[10].item, count);
-      gtk_widget_set_sensitive (toolbar_items[11].item, TRUE);
-      gtk_widget_set_sensitive (toolbar_items[12].item, arrow_select);
-      gtk_widget_set_sensitive (toolbar_items[13].item, TRUE);
-      gtk_widget_set_sensitive (toolbar_items[15].item, arrow_up);
-      gtk_widget_set_sensitive (toolbar_items[16].item, arrow_down);
+      created = orz_mdi_get_created (ORZ_MDI (mdi),
+                            orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid));
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/file/close"),
+                                                                TRUE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/file/save"),
+                                                                count);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/file/saveas"),
+                                                                count);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/file/reload"),
+                                                                !created);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/file/export"),
+                                                                arrow_select);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/tag"), TRUE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/tag/up"),
+                                                                arrow_up);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/tag/down"),
+                                                                arrow_down);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/tag/root"),
+                                                                count);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/tag/refresh"),
+                                                                count);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/tag/add"),
+                                                                TRUE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/tag/edit"),
+                                                                arrow_select);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/tag/search"),
+                                                                TRUE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/tag/cut"),
+                                                                arrow_select);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/tag/copy"),
+                                                                arrow_select);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/tag/delete"),
+                                                                arrow_select);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                    "save")), count);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                    "cut")), arrow_select);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                    "copy")), arrow_select);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                    "paste")), TRUE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                    "delete")), arrow_select);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                    "root")), count);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                    "refresh")), count);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                    "add")), TRUE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                    "edit")), arrow_select);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                    "search")), TRUE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                    "up")), arrow_up);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                    "down")), arrow_down);
     }
   else
     {
-      gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU
-            (gtk_item_factory_get_widget (ifactory_menu, "<main>/Tag"))),
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/file/close"),
                                                                         FALSE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Close"), FALSE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Save"), FALSE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Save As..."), FALSE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Reload..."), FALSE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Export..."), FALSE);
-      gtk_widget_set_sensitive (toolbar_items[ 2].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[ 4].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[ 5].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[ 6].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[ 7].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[ 9].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[10].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[11].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[12].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[13].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[15].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[16].item, FALSE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/file/save"),
+                                                                        FALSE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/file/saveas"),
+                                                                        FALSE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/file/reload"),
+                                                                        FALSE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/file/export"),
+                                                                        FALSE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/tag"), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "save")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "cut")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "copy")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "paste")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "delete")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "root")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "refresh")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "add")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "edit")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "search")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "up")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "down")), FALSE);
     }
 }
 
@@ -170,13 +190,13 @@ prompt_close (MmaidWindow *mmaid)
 {
   gint page;
 
-  page = misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid);
-  if (misc_mdi_get_edited (MISC_MDI (mdi), page))
+  page = orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid);
+  if (orz_mdi_get_edited (ORZ_MDI (mdi), page))
     {
       gchar *text, *utf8str;
 
       utf8str = g_filename_to_utf8
-            (misc_mdi_get_file (MISC_MDI (mdi), page), -1, NULL, NULL, NULL);
+                (orz_mdi_get_file (ORZ_MDI (mdi), page), -1, NULL, NULL, NULL);
       text = g_strdup_printf (_("File %s was edited.\nSave?"), utf8str);
       g_free (utf8str);
       switch (misc_message_box ("Melody maid", text, 0,
@@ -191,10 +211,10 @@ prompt_close (MmaidWindow *mmaid)
                 gtk_notebook_set_current_page (GTK_NOTEBOOK (mdi), page);
               else
                 page_num = -1;
-              command_save (NULL, 0, NULL);
+              command_save (NULL, NULL);
               if (page_num >= 0)
                 gtk_notebook_set_current_page (GTK_NOTEBOOK (mdi), page_num);
-              if (!misc_mdi_get_edited (MISC_MDI (mdi), page))
+              if (!orz_mdi_get_edited (ORZ_MDI (mdi), page))
                 break;
             }
           case 2:
@@ -224,11 +244,11 @@ charlist_renewal_all (const gchar *charlist)
       g_free (charset_list);
       charset_list = tmp;
     }
-  for (i = misc_mdi_get_n_pages (MISC_MDI (mdi)) - 1; i >= 0; i--)
+  for (i = orz_mdi_get_n_pages (ORZ_MDI (mdi)) - 1; i >= 0; i--)
     {
       MmaidWindow *mmaid;
 
-      mmaid = misc_mdi_get_data (MISC_MDI (mdi), i);
+      mmaid = orz_mdi_get_data (ORZ_MDI (mdi), i);
       if (mmaid->charset != charlist)
         {
           tmp = charuty_rename (mmaid->charset, charlist);
