@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -46,12 +46,10 @@ gboolean
 prompt_close (MmaidWindow *mmaid);
 
 
-/*  ja:タブの編集済みマークの変更
-      mmaid,ウインドウ情報
-    is_edit,TRUE:編集済み,FALSE:未編集                                      */
+/*  ja:文字符号化方式を置換する
+    charlist,置換する文字符号化方式                                         */
 void
-mmaid_change_edit (MmaidWindow *mmaid,
-                   gboolean     is_edit);
+charlist_renewal_all (const gchar *charlist);
 
 
 /******************************************************************************
