@@ -31,14 +31,18 @@ static void mm_list_destroy    (GtkObject   *object);
 enum
 {
   CHANGED_SIGNAL,
-  CLICKED_SIGNAL,
   DELETED_SIGNAL,
   EDITED_SIGNAL,
   INSERTED_SIGNAL,
   MOVED_SIGNAL,
+  SORTED_SIGNAL,
   TOGGLED_SIGNAL,
   LAST_SIGNAL
 };
+enum
+{
+  TARGET_MMAID_ID3TAG
+};
 
 
 static GtkWindowClass *parent_class = NULL;
@@ -91,11 +95,11 @@ mm_list_class_init (MmListClass *klass)
   object_class->destroy = mm_list_destroy;
 
   klass->changed  = NULL;
-  klass->clicked  = NULL;
   klass->deleted  = NULL;
   klass->edited   = NULL;
   klass->inserted = NULL;
   klass->moved    = NULL;
+  klass->sorted  = NULL;
   klass->toggled  = NULL;
 
   mm_list_signals[CHANGED_SIGNAL]
@@ -106,14 +110,6 @@ mm_list_class_init (MmListClass *klass)
                                 NULL, NULL,
                                 g_cclosure_marshal_VOID__VOID,
                                 G_TYPE_NONE, 0);
-  mm_list_signals[CLICKED_SIGNAL]
-                = g_signal_new ("clicked",
-                                G_TYPE_FROM_CLASS (klass),
-                                G_SIGNAL_RUN_FIRST | G_SIGNAL_DETAILED,
-                                G_STRUCT_OFFSET (MmListClass, clicked),
-                                NULL, NULL,
-                                g_cclosure_marshal_VOID__VOID,
-                                G_TYPE_NONE, 0);
   mm_list_signals[DELETED_SIGNAL]
                 = g_signal_new ("deleted",
                                 G_TYPE_FROM_CLASS (klass),
@@ -146,6 +142,14 @@ mm_list_class_init (MmListClass *klass)
                                 NULL, NULL,
                                 gtk_marshal_VOID__INT_INT,
                                 G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
+  mm_list_signals[SORTED_SIGNAL]
+                = g_signal_new ("sorted",
+                                G_TYPE_FROM_CLASS (klass),
+                                G_SIGNAL_RUN_FIRST | G_SIGNAL_DETAILED,
+                                G_STRUCT_OFFSET (MmListClass, sorted),
+                                NULL, NULL,
+                                g_cclosure_marshal_VOID__VOID,
+                                G_TYPE_NONE, 0);
   mm_list_signals[TOGGLED_SIGNAL]
                 = g_signal_new ("toggled",
                                 G_TYPE_FROM_CLASS (klass),
@@ -203,7 +207,7 @@ mm_list_clicked (GtkTreeViewColumn *column,
         break;
       default:
         if (list->signal)
-          g_signal_emit_by_name (G_OBJECT (list), "clicked");
+          g_signal_emit_by_name (G_OBJECT (list), "sorted");
         return;
     }
   count = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (list->store), NULL);
@@ -326,6 +330,17 @@ mm_list_edited (GtkCellRendererText *cell,
 }
 
 
+/* ja:ドロップされたとき */
+static void
+mm_list_drag_end (GtkWidget      *widget,
+                  GdkDragContext *drag_context,
+                  gpointer        user_data)
+{
+  if (MM_LIST (widget)->signal)
+    g_signal_emit_by_name (G_OBJECT (widget), "sorted");
+}
+
+
 static void
 mm_list_init (MmList *list)
 {
@@ -334,6 +349,7 @@ mm_list_init (MmList *list)
   static gchar *title[] = {N_("File"),  N_("Title"), N_("Artist"),
                            N_("Album"), N_("Year"),  N_("Comment"),
                            N_("Track"), N_("Genre"), N_("Character Encoding")};
+  GtkTargetEntry dnd_entries[1] = {{"GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET | GTK_TARGET_SAME_WIDGET, TARGET_MMAID_ID3TAG}};
 
   list->editable       = FALSE;
   list->editable_file  = FALSE;
@@ -392,6 +408,13 @@ mm_list_init (MmList *list)
   gtk_tree_selection_set_mode (select, GTK_SELECTION_MULTIPLE);
   g_signal_connect (G_OBJECT (select), "changed",
                                         G_CALLBACK (mm_list_changed), list);
+  /* en:Drag & Drop */
+  gtk_tree_view_enable_model_drag_dest (GTK_TREE_VIEW (list),
+                                            dnd_entries, 1, GDK_ACTION_MOVE);
+  gtk_tree_view_enable_model_drag_source (GTK_TREE_VIEW (list),
+                            GDK_BUTTON1_MASK, dnd_entries, 1, GDK_ACTION_MOVE);
+  g_signal_connect (G_OBJECT (list), "drag-end",
+                                        G_CALLBACK (mm_list_drag_end), NULL);
 }
 
 
