@@ -63,11 +63,11 @@ struct _MmListClass
 
   /* -- signals -- */
   void (*changed)  (MmList *list);
-  void (*clicked)  (MmList *list);
   void (*deleted)  (MmList *list);
   void (*edited)   (MmList *list, const gint n, const gint c);
   void (*inserted) (MmList *list, const gint n);
   void (*moved)    (MmList *list, const gint n0, const gint n1);
+  void (*sorted)   (MmList *list);
   void (*toggled)  (MmList *list, const gint c);
 };
 
