@@ -23,20 +23,18 @@
 #include "general.h"
 #include "genre.h"
 #include "mm_list.h"
-#include "process.h"
 #include "sigmain.h"
 #include "toolbar.h"
-#include "version.h"
 #include "misc/argument.h"
 #include "misc/charuty.h"
 #include "misc/fileio.h"
 #include "misc/license.h"
-#include "misc/misc_accel.h"
-#include "misc/misc_comm.h"
-#include "misc/misc_history.h"
-#include "misc/misc_mdi.h"
-#include "misc/misc_winmenu.h"
 #include "misc/profile.h"
+#include "orz/orzaccel.h"
+#include "orz/orzcomm.h"
+#include "orz/orzhistory.h"
+#include "orz/orzmdi.h"
+#include "orz/orzwinmenu.h"
 
 
 gboolean newfile = FALSE;           /* ja:TRUE:新規ファイル,FALSE:なし */
@@ -59,13 +57,66 @@ GdkAtom atom_id3tag;                /* ja:ID3タグ */
 GtkWidget *window;                  /* ja:ウインドウ */
 GtkWidget *mdi;                     /* en:MDI */
 GtkPositionType n_pos = GTK_POS_TOP;/* ja:ノートブックの位置 */
-GtkItemFactory *ifactory_menu;      /* ja:メニュー */
-GtkItemFactory *ifactory_popup;     /* ja:ポップアップ */
 GtkTargetEntry targets_mmaid[] = {  /* ja:提供可能なセレクション */
     {"Melody maid ID3 Tag", 0, TARGET_MMAID}};
 #ifdef G_OS_WIN32
 UINT uFormat = 0;                   /* ja:クリップボード */
 #endif /* G_OS_WIN32 */
+MiscCreateMenuEntry menu_entries[] = {
+{"/",                     NULL,                         NULL,              MISC_CREATE_MENU_BAR,       NULL,            NULL, NULL},
+{"/file",                 N_("_File"),                  NULL,              MISC_CREATE_MENU_ITEM,      NULL,            NULL, NULL},
+{"/file/",                NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,            NULL, NULL},
+{"/file/new",             N_("_New"),                   "<control>N",      MISC_CREATE_MENU_ITEM,      command_new,     NULL, NULL},
+{"/file/open",            N_("_Open..."),               "<control>O",      MISC_CREATE_MENU_ITEM,      command_open,    NULL, NULL},
+{"/file/close",           N_("_Close"),                 "<control>W",      MISC_CREATE_MENU_ITEM,      command_close,   NULL, NULL},
+{"/file/save",            N_("_Save"),                  "<control>S",      MISC_CREATE_MENU_ITEM,      command_save,    NULL, NULL},
+{"/file/saveas",          N_("Save _As..."),            "<control>S",      MISC_CREATE_MENU_ITEM,      command_save,    NULL, NULL},
+{"/file/reload",          N_("_Reload..."),             "<control>R",      MISC_CREATE_MENU_ITEM,      command_reload,  NULL, NULL},
+{"/file/sep1",            NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
+{"/file/export",          N_("_Export..."),             "<control>E",      MISC_CREATE_MENU_ITEM,      command_export,  NULL, NULL},
+{"/file/sep2",            NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
+{"/file/exit",            N_("E_xit"),                  "<control>Q",      MISC_CREATE_MENU_ITEM,      command_exit,    NULL, NULL},
+{"/tag",                  N_("_Tag"),                   NULL,              MISC_CREATE_MENU_ITEM,      NULL,            NULL, NULL},
+{"/tag/",                 NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,            NULL, NULL},
+{"/tag/up",               N_("Up"),                     NULL,              MISC_CREATE_MENU_ITEM,      command_up,      NULL, NULL},
+{"/tag/down",             N_("_Down"),                  NULL,              MISC_CREATE_MENU_ITEM,      command_down,    NULL, NULL},
+{"/tag/sep1",             NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
+{"/tag/root",             N_("R_oot..."),               "<control>H",      MISC_CREATE_MENU_ITEM,      command_root,    NULL, NULL},
+{"/tag/refresh",          N_("_Refresh..."),            "F5",              MISC_CREATE_MENU_ITEM,      command_refresh, NULL, NULL},
+{"/tag/add",              N_("A_dd..."),                "Insert",          MISC_CREATE_MENU_ITEM,      command_add,     NULL, NULL},
+{"/tag/edit",             N_("_Edit..."),               "<control>Return", MISC_CREATE_MENU_ITEM,      command_edit,    NULL, NULL},
+{"/tag/search",           N_("_Search..."),             "<control>F",      MISC_CREATE_MENU_ITEM,      command_search,  NULL, NULL},
+{"/tag/sep2",             NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
+{"/tag/cut",              N_("Cu_t"),                   "<control>X",      MISC_CREATE_MENU_ITEM,      command_cut,     NULL, NULL},
+{"/tag/copy",             N_("_Copy"),                  "<control>C",      MISC_CREATE_MENU_ITEM,      command_copy,    NULL, NULL},
+{"/tag/paste",            N_("_Paste"),                 "<control>V",      MISC_CREATE_MENU_ITEM,      command_paste,   NULL, NULL},
+{"/tag/delete",           N_("De_lete"),                "Delete",          MISC_CREATE_MENU_ITEM,      command_delete,  NULL, NULL},
+{"/tag/sep3",             NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
+{"/tag/all",              N_("_All"),                   "<control>A",      MISC_CREATE_MENU_ITEM,      command_all,     NULL, NULL},
+{"/option",               N_("_Option"),                NULL,              MISC_CREATE_MENU_ITEM,      NULL,            NULL, NULL},
+{"/option/",              NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,            NULL, NULL},
+{"/option/configuration", N_("_Configuration..."),      NULL,              MISC_CREATE_MENU_ITEM,      command_conf,    NULL, NULL},
+{"/option/genre",         N_("_Genre..."),              NULL,              MISC_CREATE_MENU_ITEM,      command_genre,   NULL, NULL},
+{"/option/character",     N_("Character _Encoding..."), NULL,              MISC_CREATE_MENU_ITEM,      command_charset, NULL, NULL},
+{"/option/process",       N_("_Process..."),            NULL,              MISC_CREATE_MENU_ITEM,      command_process, NULL, NULL},
+{"/window",               N_("_Window"),                NULL,              MISC_CREATE_MENU_ITEM,      NULL,            NULL, NULL},
+{"/window/",              NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,            NULL, NULL},
+{"/help",                 N_("_Help"),                  NULL,              MISC_CREATE_MENU_ITEM,      NULL,            NULL, NULL},
+{"/help/",                NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,            NULL, NULL},
+{"/help/about",           N_("_About..."),              NULL,              MISC_CREATE_MENU_ITEM,      command_version, NULL, NULL},
+{NULL,                    NULL,                         NULL,              MISC_CREATE_MENU_TERMINAL,  NULL,            NULL, NULL}};
+MiscCreateMenuEntry popup_entries[] = {
+{"/",                     NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,            NULL, NULL},
+{"/play",                 N_("Play"),                   NULL,              MISC_CREATE_MENU_ITEM,      command_play,    NULL, NULL},
+{"/stop",                 N_("Stop"),                   NULL,              MISC_CREATE_MENU_ITEM,      command_stop,    NULL, NULL},
+{"/sep1",                 NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
+{"/cut",                  N_("Cu_t"),                   "<control>X",      MISC_CREATE_MENU_ITEM,      command_cut,     NULL, NULL},
+{"/copy",                 N_("_Copy"),                  "<control>C",      MISC_CREATE_MENU_ITEM,      command_copy,    NULL, NULL},
+{"/paste",                N_("_Paste"),                 "<control>V",      MISC_CREATE_MENU_ITEM,      command_paste,   NULL, NULL},
+{"/delete",               N_("De_lete"),                "Delete",          MISC_CREATE_MENU_ITEM,      command_delete,  NULL, NULL},
+{"/sep2",                 NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
+{"/all",                  N_("_All"),                   "<control>A",      MISC_CREATE_MENU_ITEM,      command_all,     NULL, NULL},
+{NULL,                    NULL,                         NULL,              MISC_CREATE_MENU_TERMINAL,  NULL,            NULL, NULL}};
 
 
 /******************************************************************************
@@ -73,14 +124,6 @@ UINT uFormat = 0;                   /* ja:クリップボード */
 * ja:メイン関数                                                               *
 *                                                                             *
 ******************************************************************************/
-static gchar *
-menu_translate (const gchar *path,
-                gpointer     func_data)
-{
-  return _(path);
-}
-
-
 int
 main (int   argc,
       char *argv[])
@@ -92,53 +135,7 @@ main (int   argc,
   Profile *profile;
   GObject *accel, *winmenu;
   GtkAccelGroup *accel_group;
-  GtkWidget *menu_bar, *handle, *toolbar, *vbox;
-  GtkItemFactoryEntry menu_items[] = {
-{N_("/_File"),                         NULL,              NULL,            0, "<Branch>"},
-{N_("/File/_New"),                     "<control>N",      command_new,     0, "<Item>"},
-{N_("/File/_Open..."),                 "<control>O",      command_open,    0, "<Item>"},
-{N_("/File/_Close"),                   "<control>W",      command_close,   0, "<Item>"},
-{N_("/File/_Save"),                    "<control>S",      command_save,    0, "<Item>"},
-{N_("/File/Save _As..."),              NULL,              command_saveas,  0, "<Item>"},
-{N_("/File/_Reload..."),               "<control>R",      command_reload,  0, "<Item>"},
-{N_("/File/Sep1"),                     NULL,              NULL,            0, "<Separator>"},
-{N_("/File/_Export..."),               "<control>E",      command_export,  0, "<Item>"},
-{N_("/File/Sep2"),                     NULL,              NULL,            0, "<Separator>"},
-{N_("/File/E_xit"),                    "<control>Q",      command_exit,    0, "<Item>"},
-{N_("/_Tag"),                          NULL,              NULL,            0, "<Branch>"},
-{N_("/Tag/_Up"),                       NULL,              command_up,      0, "<Item>"},
-{N_("/Tag/_Down"),                     NULL,              command_down,    0, "<Item>"},
-{N_("/Tag/Sep1"),                      NULL,              NULL,            0, "<Separator>"},
-{N_("/Tag/R_oot..."),                  "<control>H",      command_root,    0, "<Item>"},
-{N_("/Tag/_Refresh..."),               "F5",              command_refresh, 0, "<Item>"},
-{N_("/Tag/A_dd..."),                   "Insert",          command_add,     0, "<Item>"},
-{N_("/Tag/_Edit..."),                  "<control>Return", command_edit,    0, "<Item>"},
-{N_("/Tag/_Search..."),                "<control>F",      command_search,  0, "<Item>"},
-{N_("/Tag/Sep2"),                      NULL,              NULL,            0, "<Separator>"},
-{N_("/Tag/Cu_t"),                      "<control>X",      command_cut,     0, "<Item>"},
-{N_("/Tag/_Copy"),                     "<control>C",      command_copy,    0, "<Item>"},
-{N_("/Tag/_Paste"),                    "<control>V",      command_paste,   0, "<Item>"},
-{N_("/Tag/De_lete"),                   "Delete",          command_delete,  0, "<Item>"},
-{N_("/Tag/Sep3"),                      NULL,              NULL,            0, "<Separator>"},
-{N_("/Tag/_All"),                      "<control>A",      command_all,     0, "<Item>"},
-{N_("/_Option"),                       NULL,              NULL,            0, "<Branch>"},
-{N_("/Option/_Configuration..."),      NULL,              command_conf,    0, "<Item>"},
-{N_("/Option/_Genre..."),              NULL,              genre_dialog,    0, "<Item>"},
-{N_("/Option/Character _Encoding..."), NULL,              command_charset, 0, "<Item>"},
-{N_("/Option/_Process..."),            NULL,              process_dialog,  0, "<Item>"},
-{N_("/_Window"),                       NULL,              NULL,            0, "<Branch>"},
-{N_("/_Help"),                         NULL,              NULL,            0, "<Branch>"},
-{N_("/Help/_About..."),                NULL,              version_dialog,  0, "<Item>"}};
-    GtkItemFactoryEntry popup_items[] = {
-{N_("/Play"),                          NULL,              command_play,    0, "<Item>"},
-{N_("/Stop"),                          NULL,              command_stop,    0, "<Item>"},
-{"/Sep1",                              NULL,              NULL,            0, "<Separator>"},
-{N_("/Cu_t"),                          "<control>X",      command_cut,     0, "<Item>"},
-{N_("/_Copy"),                         "<control>C",      command_copy,    0, "<Item>"},
-{N_("/_Paste"),                        "<control>V",      command_paste,   0, "<Item>"},
-{N_("/De_lete"),                       "Delete",          command_delete,  0, "<Item>"},
-{"/Sep2",                              NULL,              NULL,            0, "<Separator>"},
-{N_("/_All"),                          "<control>A",      command_all,     0, "<Item>"}};
+  GtkWidget *handle, *vbox;
   /* Drag&Drop */
   GtkTargetEntry drag_types[1] = {{"text/uri-list", 0, 0}};
 
@@ -169,7 +166,7 @@ main (int   argc,
   g_memset (genre, 0, sizeof (gchar *) * 256 * 256);
 
   /* ja:ファイルの履歴 */
-  history = misc_history_new ();
+  history = orz_history_new ();
 
   /* ja:レジストリから読み出す */
   profile = profile_open (NULL);
@@ -183,7 +180,7 @@ main (int   argc,
         license = FALSE;
       if (profile_get_value (profile, "mmaid", "history",
                 (gpointer)&num, sizeof (gint), PROFILE_VALUE_TYPE_INT))
-        misc_history_set_num (MISC_HISTORY (history), num);
+        orz_history_set_num (ORZ_HISTORY (history), num);
       if (!profile_get_value (profile, "mmaid", "newfile",
                 (gpointer)&newfile, sizeof (gboolean),
                                                     PROFILE_VALUE_TYPE_BOOL))
@@ -230,7 +227,7 @@ main (int   argc,
                 ? g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL) : NULL;
       g_free (utf8str);
       /* ja:ファイルの履歴 */
-      for (i = misc_history_get_num (MISC_HISTORY (history)) - 1; i >= 0; i--)
+      for (i = orz_history_get_num (ORZ_HISTORY (history)) - 1; i >= 0; i--)
         {
           key = g_strdup_printf ("history%d", i);
           utf8str = profile_get_string (profile, "mmaid", key);
@@ -241,7 +238,7 @@ main (int   argc,
 
               file = g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL);
               g_free (utf8str);
-              misc_history_add_file (MISC_HISTORY (history), file);
+              orz_history_add_file (ORZ_HISTORY (history), file);
               g_free (file);
             }
         }
@@ -330,7 +327,7 @@ main (int   argc,
 {NULL,      '\0', NULL,           NULL,              0,                   NULL}};
 
     /* ja:ファイルの履歴 */
-    arg_h.val = misc_history_get_num (MISC_HISTORY (history));
+    arg_h.val = orz_history_get_num (ORZ_HISTORY (history));
     arg_h.def = 4;
     /* ja:新規ファイル */
     arg_n.flag = newfile;
@@ -355,7 +352,7 @@ MMAID_COPYRIGHT_NOTICE"\n"
     /* ja:ヘルプ */
     arg_q.str = MMAID_COPYRIGHT_NOTICE"\n\n";
     arg_files = arg_analyse (argv, arg_opts);
-    misc_history_set_num (MISC_HISTORY (history), arg_h.val);
+    orz_history_set_num (ORZ_HISTORY (history), arg_h.val);
     def_width = array[0];
     def_height = array[1];
     second = arg_x.flag;
@@ -370,6 +367,7 @@ MMAID_COPYRIGHT_NOTICE"\n"
   g_signal_connect (G_OBJECT (window), "destroy",
                                             G_CALLBACK (gtk_main_quit), NULL);
   gtk_widget_realize (window);
+  gtk_widget_add_events (window, GDK_KEY_PRESS_MASK);
   /* en:Drag and Drop */
   gtk_drag_dest_set (window, GTK_DEST_DEFAULT_MOTION
                         | GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP,
@@ -392,7 +390,7 @@ MMAID_COPYRIGHT_NOTICE"\n"
   g_signal_connect (G_OBJECT (window), "selection-received",
                                 G_CALLBACK (signal_selection_received), NULL);
   /* en:MDI */
-  mdi = misc_mdi_new ();
+  mdi = orz_mdi_new ();
   gtk_notebook_set_scrollable (GTK_NOTEBOOK (mdi), TRUE);
   gtk_notebook_set_tab_pos (GTK_NOTEBOOK (mdi), n_pos);
   g_signal_connect (G_OBJECT (mdi), "close-window",
@@ -401,70 +399,35 @@ MMAID_COPYRIGHT_NOTICE"\n"
                                 G_CALLBACK (signal_switch_window), NULL);
   /* ja:ポップアップ */
   accel_group = gtk_accel_group_new ();
-  ifactory_popup = gtk_item_factory_new (GTK_TYPE_MENU, "<main>", accel_group);
-  gtk_item_factory_set_translate_func (ifactory_popup, menu_translate,
-                                                                NULL, NULL);
-  gtk_item_factory_create_items (ifactory_popup,
-    sizeof (popup_items) / sizeof (GtkItemFactoryEntry), popup_items, NULL);
+  misc_create_menu (popup_entries, accel_group);
   /* ja:メニュー */
   accel_group = gtk_accel_group_new ();
-  ifactory_menu = gtk_item_factory_new (GTK_TYPE_MENU_BAR,
-                                                        "<main>", accel_group);
-  gtk_item_factory_set_translate_func (ifactory_menu, menu_translate,
-                                                                NULL, NULL);
-  gtk_item_factory_create_items (ifactory_menu,
-        sizeof(menu_items) / sizeof (GtkItemFactoryEntry), menu_items, NULL);
-  gtk_widget_add_events (window, GDK_KEY_PRESS_MASK);
-  menu_bar = gtk_item_factory_get_widget (ifactory_menu, "<main>");
+  misc_create_menu (menu_entries, accel_group);
   /* ja:ファイルの履歴 */
-  misc_history_set_menu (MISC_HISTORY (history),
-    gtk_item_factory_get_widget (ifactory_menu, "<main>/File"), MENUFILE - 2);
-  g_signal_connect (MISC_HISTORY (history), "activate",
+  orz_history_set_menu (ORZ_HISTORY (history),
+                        misc_find_menu (menu_entries, "/file/"), MENUFILE - 2);
+  g_signal_connect (ORZ_HISTORY (history), "activate",
                             G_CALLBACK (signal_activate_menu_history), NULL);
   /* ja:ウインドウメニュー */
-  winmenu = misc_winmenu_new ();
-  misc_winmenu_set_mdi (MISC_WINMENU (winmenu), MISC_MDI (mdi));
-  misc_winmenu_set_menu (MISC_WINMENU (winmenu),
-            gtk_item_factory_get_widget (ifactory_menu, "<main>/Window"), 0);
+  winmenu = orz_winmenu_new ();
+  orz_winmenu_set_mdi (ORZ_WINMENU (winmenu), ORZ_MDI (mdi));
+  orz_winmenu_set_menu (ORZ_WINMENU (winmenu),
+                                misc_find_menu (menu_entries, "/window/"), 0);
   /* ja:アクセルグループ */
-  accel = misc_accel_new ();
-  misc_accel_set_window (MISC_ACCEL (accel), GTK_WINDOW (window));
-  misc_accel_add_accel_group (MISC_ACCEL (accel), accel_group);
-  /* ja:ツールバー */
-  toolbar = gtk_toolbar_new ();
-  gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
-                                                GTK_ORIENTATION_HORIZONTAL);
-  gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
-  for (i = 0; toolbar_items[i].name != (gpointer)-1; i++)
-    if (toolbar_items[i].name)
-      {
-        GdkBitmap *mask;
-        GdkPixmap *pixmap;
-
-        pixmap = gdk_pixmap_create_from_xpm_d (window->window,
-                                            &mask, NULL, toolbar_items[i].xpm);
-        toolbar_items[i].item = gtk_toolbar_append_item
-                                (GTK_TOOLBAR (toolbar),
-                                 NULL,
-                                 _(toolbar_items[i].name),
-                                 NULL,
-                                 gtk_pixmap_new (pixmap, mask),
-                                 GTK_SIGNAL_FUNC (toolbar_items[i].callback),
-                                 toolbar_items[i].user_data);
-      }
-    else
-      {
-        gtk_toolbar_append_space (GTK_TOOLBAR (toolbar));
-      }
+  accel = orz_accel_new ();
+  orz_accel_set_window (ORZ_ACCEL (accel), GTK_WINDOW (window));
+  orz_accel_add_accel_group (ORZ_ACCEL (accel), accel_group);
   /* ja:垂直ボックス/ハンドルボックス */
   vbox = gtk_vbox_new (FALSE, 0);
   handle = gtk_handle_box_new ();
   gtk_container_set_border_width (GTK_CONTAINER (handle), 2);
-  gtk_container_add (GTK_CONTAINER (handle), menu_bar);
+  gtk_container_add (GTK_CONTAINER (handle),
+                                        misc_find_menu (menu_entries, "/"));
   gtk_box_pack_start (GTK_BOX (vbox), handle, FALSE, FALSE, 0);
   handle = gtk_handle_box_new ();
   gtk_container_set_border_width (GTK_CONTAINER (handle), 2);
-  gtk_container_add (GTK_CONTAINER (handle), toolbar);
+  gtk_container_add (GTK_CONTAINER (handle),
+                                        misc_create_toolbar (toolbar_entries));
   gtk_box_pack_start (GTK_BOX (vbox), handle, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), mdi, TRUE, TRUE, 0);
   gtk_container_add (GTK_CONTAINER (window), vbox);
@@ -477,10 +440,10 @@ MMAID_COPYRIGHT_NOTICE"\n"
     {
       GObject *comm;
 
-      comm = misc_comm_new (window, "Melody maid InterProcess communication");
-      if (!misc_comm_is_first (MISC_COMM (comm)))
+      comm = orz_comm_new (window, "Melody maid InterProcess communication");
+      if (!orz_comm_is_first (ORZ_COMM (comm)))
         {
-          misc_comm_send_with_files (MISC_COMM (comm), argc, argv, arg_files);
+          orz_comm_send_with_files (ORZ_COMM (comm), argc, argv, arg_files);
           gtk_exit (0);
         }
       g_signal_connect (G_OBJECT (comm), "recv",
@@ -519,8 +482,8 @@ MMAID_COPYRIGHT_NOTICE"\n"
                       count++;
                     }
                   mm_list_append (MM_LIST (mmaid->list), id3tag);
-                  misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid), TRUE);
+                  orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid), TRUE);
                 }
             }
         }
@@ -537,7 +500,7 @@ MMAID_COPYRIGHT_NOTICE"\n"
       gint num;
       GList *glist;
 
-      num = misc_history_get_num (MISC_HISTORY (history));
+      num = orz_history_get_num (ORZ_HISTORY (history));
       profile_set_value (profile, "mmaid", "license",
             (gpointer)&license, sizeof (gboolean), PROFILE_VALUE_TYPE_BOOL);
       profile_set_value (profile, "mmaid", "history",
@@ -592,7 +555,7 @@ MMAID_COPYRIGHT_NOTICE"\n"
             }
         }
       /* ja:ファイルの履歴 */
-      glist = misc_history_get_file (MISC_HISTORY (history));
+      glist = orz_history_get_file (ORZ_HISTORY (history));
       for (i = 0; i < g_list_length (glist); i++)
         {
           key = g_strdup_printf ("history%d", i);
@@ -608,7 +571,7 @@ MMAID_COPYRIGHT_NOTICE"\n"
           g_free (key);
         }
       g_list_free (glist);
-      while (i <= MISC_HISTORY_NUM_MAX)
+      while (i <= ORZ_HISTORY_NUM_MAX)
         {
           key = g_strdup_printf ("history%d", i++);
           profile_delete_key (profile, "mmaid", key);
