@@ -21,6 +21,7 @@
 
 
 #include "common.h"
+#include "misc/misc.h"
 #ifdef G_OS_WIN32
 # include <tchar.h>
 # include <windows.h>
@@ -85,11 +86,11 @@ extern GdkAtom atom_id3tag;             /* ja:ID3タグ */
 extern GtkWidget *window;               /* ja:ウインドウ */
 extern GtkWidget *mdi;                  /* en:MDI */
 extern GtkPositionType n_pos;           /* ja:ノートブックの位置 */
-extern GtkItemFactory *ifactory_menu;   /* ja:メニュー */
-extern GtkItemFactory *ifactory_popup;  /* ja:ポップアップ */
 #ifdef G_OS_WIN32
 extern UINT uFormat;                    /* ja:クリップボード */
 #endif /* G_OS_WIN32 */
+extern MiscCreateMenuEntry menu_entries[];
+extern MiscCreateMenuEntry popup_entries[];
 
 
 #ifdef __cplusplus
