@@ -23,7 +23,7 @@
 #include "sigfile.h"
 #include "misc/fileio.h"
 #include "misc/misc.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -52,36 +52,35 @@ signal_button_press (GtkWidget      *widget,
             arrow_select = TRUE;
             break;
           }
-      if (cmd_play != NULL || cmd_stop != NULL)
+      if (cmd_play || cmd_stop )
         {
-          gtk_widget_show (gtk_item_factory_get_widget
-                                            (ifactory_popup, "<main>/Play"));
-          gtk_widget_show (gtk_item_factory_get_widget
-                                            (ifactory_popup, "<main>/Stop"));
-          gtk_widget_show (gtk_item_factory_get_widget
-                                            (ifactory_popup, "<main>/Sep1"));
-          gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                            (ifactory_popup, "<main>/Play"), n >= 0);
-          gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                            (ifactory_popup, "<main>/Stop"), cmd_stop != NULL);
+          gtk_widget_show (misc_find_menu (popup_entries, "/play"));
+          gtk_widget_show (misc_find_menu (popup_entries, "/stop"));
+          gtk_widget_show (misc_find_menu (popup_entries, "/sep1"));
+          gtk_widget_set_sensitive (misc_find_menu (popup_entries, "/play"),
+                                                                    n >= 0);
+          gtk_widget_set_sensitive (misc_find_menu (popup_entries, "/stop"),
+                                                            cmd_stop != NULL);
         }
       else
         {
-          gtk_widget_hide (gtk_item_factory_get_widget
-                                            (ifactory_popup, "<main>/Play"));
-          gtk_widget_hide (gtk_item_factory_get_widget
-                                            (ifactory_popup, "<main>/Stop"));
-          gtk_widget_hide (gtk_item_factory_get_widget
-                                            (ifactory_popup, "<main>/Sep1"));
+          gtk_widget_hide (misc_find_menu (popup_entries, "/play"));
+          gtk_widget_hide (misc_find_menu (popup_entries, "/stop"));
+          gtk_widget_hide (misc_find_menu (popup_entries, "/sep1"));
         }
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                            (ifactory_popup, "<main>/Cut"), arrow_select);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                            (ifactory_popup, "<main>/Copy"), arrow_select);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                            (ifactory_popup, "<main>/Delete"), arrow_select);
-      gtk_menu_popup (GTK_MENU
-                    (gtk_item_factory_get_widget (ifactory_popup,"<main>")),
+      gtk_widget_show (misc_find_menu (popup_entries, "/cut"));
+      gtk_widget_show (misc_find_menu (popup_entries, "/copy"));
+      gtk_widget_show (misc_find_menu (popup_entries, "/paste"));
+      gtk_widget_show (misc_find_menu (popup_entries, "/delete"));
+      gtk_widget_show (misc_find_menu (popup_entries, "/sep2"));
+      gtk_widget_show (misc_find_menu (popup_entries, "/all"));
+      gtk_widget_set_sensitive (misc_find_menu (popup_entries, "/cut"),
+                                                                arrow_select);
+      gtk_widget_set_sensitive (misc_find_menu (popup_entries, "/copy"),
+                                                                arrow_select);
+      gtk_widget_set_sensitive (misc_find_menu (popup_entries, "/delete"),
+                                                                arrow_select);
+      gtk_menu_popup (GTK_MENU (misc_find_menu (popup_entries, "/")),
                         NULL, NULL, NULL, NULL, event->button, event->time);
       return TRUE;
     }
@@ -98,18 +97,7 @@ void
 signal_changed (GtkWidget   *widget,
                 MmaidWindow *mmaid)
 {
-  if (mmaid == misc_mdi_get_data (MISC_MDI (mdi), -1))
-    set_menu_bar (mmaid);
-}
-
-
-void
-signal_clicked (GtkWidget   *widget,
-                MmaidWindow *mmaid)
-{
-  misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid), TRUE);
-  if (mmaid == misc_mdi_get_data (MISC_MDI (mdi), -1))
+  if (mmaid == orz_mdi_get_data (ORZ_MDI (mdi), -1))
     set_menu_bar (mmaid);
 }
 
@@ -122,9 +110,9 @@ signal_edited (GtkWidget   *widget,
 {
   if (c == MM_LIST_ID3TAG || c == MM_LIST_FILE || c == MM_LIST_TITLE
             || c == MM_LIST_ARTIST || c == MM_LIST_ALBUM || c == MM_LIST_GENRE)
-    misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid), TRUE);
-  if (mmaid == misc_mdi_get_data (MISC_MDI (mdi), -1))
+    orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid), TRUE);
+  if (mmaid == orz_mdi_get_data (ORZ_MDI (mdi), -1))
     set_menu_bar (mmaid);
 }
 
@@ -134,9 +122,9 @@ signal_inserted (GtkWidget   *widget,
                  const gint   n,
                  MmaidWindow *mmaid)
 {
-  misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid), TRUE);
-  if (mmaid == misc_mdi_get_data (MISC_MDI (mdi), -1))
+  orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid), TRUE);
+  if (mmaid == orz_mdi_get_data (ORZ_MDI (mdi), -1))
     set_menu_bar (mmaid);
 }
 
@@ -147,9 +135,20 @@ signal_moved (GtkWidget   *widget,
               const gint   n1,
               MmaidWindow *mmaid)
 {
-  misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid), TRUE);
-  if (mmaid == misc_mdi_get_data (MISC_MDI (mdi), -1))
+  orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid), TRUE);
+  if (mmaid == orz_mdi_get_data (ORZ_MDI (mdi), -1))
+    set_menu_bar (mmaid);
+}
+
+
+void
+signal_sorted (GtkWidget   *widget,
+               MmaidWindow *mmaid)
+{
+  orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid), TRUE);
+  if (mmaid == orz_mdi_get_data (ORZ_MDI (mdi), -1))
     set_menu_bar (mmaid);
 }
 
@@ -159,7 +158,7 @@ signal_destroy_list (GtkWidget   *widget,
                      MmaidWindow *mmaid)
 {
   /* ja:メニュー */
-  if (misc_mdi_get_n_pages (MISC_MDI (mdi)) <= 1)
+  if (orz_mdi_get_n_pages (ORZ_MDI (mdi)) <= 1)
     set_menu_bar (NULL);
   /* ja:メモリを解放する */
   g_free (mmaid->charset);
