@@ -24,8 +24,8 @@
 #include "sigmain.h"
 #include "misc/argument.h"
 #include "misc/misc.h"
-#include "misc/misc_history.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzhistory.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -85,7 +85,7 @@ signal_drag_data_received (GtkWidget        *widget,
   MmaidWindow *mmaid;
 
   i = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  mmaid = i >= 0 ? misc_mdi_get_data (MISC_MDI (mdi), i) : NULL;
+  mmaid = i >= 0 ? orz_mdi_get_data (ORZ_MDI (mdi), i) : NULL;
   files = g_strsplit (selection_data->data, "\r\n", G_MAXINT);
   for (i = 0; files[i]; i++)
     {
@@ -111,8 +111,8 @@ signal_drag_data_received (GtkWidget        *widget,
                                         MM_LIST_FILE, id3tag->file, -1) >= 0)
                         mmaid = file_open_edit (NULL);
                       mm_list_append (MM_LIST (mmaid->list), id3tag);
-                      misc_mdi_set_edited (MISC_MDI (mdi),
-                        misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid),
+                      orz_mdi_set_edited (ORZ_MDI (mdi),
+                            orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid),
                                                                         TRUE);
                     }
                 }
@@ -184,7 +184,7 @@ signal_selection_received (GtkWidget        *widget,
           MmaidWindow *mmaid;
 
           /* ja:貼り付け */
-          mmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+          mmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
           mm_list_get_cursor (MM_LIST (mmaid->list), &n, &c);
           mm_list_unselect_all (MM_LIST (mmaid->list));
           tag = g_strsplit (data->data, "\n", G_MAXINT);
@@ -223,8 +223,8 @@ signal_selection_received (GtkWidget        *widget,
             }
           g_strfreev (tag);
           mm_list_set_cursor (MM_LIST (mmaid->list), n, c);
-          misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid), TRUE);
+          orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid), TRUE);
         }
     }
 }
@@ -249,10 +249,10 @@ signal_selection_recv (GObject   *object,
 {NULL,      '\0', NULL,           NULL,              0,                   NULL}};
 
   i = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  mmaid = i >= 0 ? misc_mdi_get_data (MISC_MDI (mdi), i) : NULL;
+  mmaid = i >= 0 ? orz_mdi_get_data (ORZ_MDI (mdi), i) : NULL;
   /* ja:プロセス間通信 */
   /* ja:ファイルの履歴 */
-  arg_h.val = misc_history_get_num (MISC_HISTORY (history));
+  arg_h.val = orz_history_get_num (ORZ_HISTORY (history));
   arg_h.def = 4;
   /* ja:新規ファイル */
   arg_n.flag = newfile;
@@ -270,7 +270,7 @@ signal_selection_recv (GObject   *object,
   arg_x.def = FALSE;
   /* ja:コマンドラインの解析 */
   arg_files = arg_analyse (argv, arg_opts);
-  misc_history_set_num (MISC_HISTORY (history), arg_h.val);
+  orz_history_set_num (ORZ_HISTORY (history), arg_h.val);
   newfile = arg_n.flag;
   def_width = array[0];
   def_height = array[1];
@@ -296,8 +296,8 @@ signal_selection_recv (GObject   *object,
                                         MM_LIST_FILE, id3tag->file, -1) >= 0)
                     mmaid = file_open_edit (NULL);
                   mm_list_append (MM_LIST (mmaid->list), id3tag);
-                  misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid), TRUE);
+                  orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid), TRUE);
                 }
             }
         }
@@ -320,7 +320,7 @@ signal_delete (GtkWidget *widget,
   while ((page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi))) >= 0)
     {
       if (!prompt_close ((MmaidWindow *)
-                                    misc_mdi_get_data (MISC_MDI (mdi), page)))
+                                    orz_mdi_get_data (ORZ_MDI (mdi), page)))
         return TRUE;
       gtk_notebook_remove_page (GTK_NOTEBOOK (mdi), page);
     }
