@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 
 #include "mmaid.h"
+#include "misc/misc.h"
 
 
 #ifdef __cplusplus
@@ -28,17 +29,7 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-typedef struct ToolBar_Tag
-{
-  gchar                   *name;
-  gchar                  **xpm;
-  GtkItemFactoryCallback   callback;
-  gpointer                 user_data;
-  GtkWidget               *item;
-} ToolBar;
-
-
-extern ToolBar toolbar_items[];
+extern MiscCreateToolbarEntry toolbar_entries[];
 
 
 #ifdef __cplusplus
